translate.storage.versioncontrol.cvs

Package translate :: Package storage :: Package versioncontrol :: Module cvs |
[hide private]
[frames] | no frames]

# Module cvs

source code

Classes | [hide private]
| cvs Class to manage items under revision control of CVS.

Functions | [hide private]
is_available() check if cvs is installed | source code

Variables | [hide private]
| __package__ = ``'``translate.storage.versioncontrol``'``

Imports: os, GenericRevisionControlSystem, run_command